<?php
/*
Plugin Name: EveryBoard
Depends: Open Content Everyware
Description: Plan, publish and win.
Version: 1.5.4
Author: Infomaker Scandinavia AB
Author URI: http://www.infomaker.se
 */


/**
 * Contains the current version-number of Everyboard
 */
const EVERYBOARD_VERSION = '1.5.4';
const EVERYBOARD_SCRIPT_VERSION = '1.5.4';
const EVERYBOARD_JSON_FORMAT_VERSION = '1.0';
const EVERYBOARD_EW_DEPENDENCY_MIN_VERSION = '1.2.6';

/**
 * Check that the OcAPI-class exists
 * We do this to confirm that the Every-plugin has been activated
 */

load_plugin_textdomain( 'everyboard', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

$notice = everyboard_check_dependencies();
if ( empty( $notice ) ) {
    define( 'EVERYBOARD_BASE', plugin_dir_url( __FILE__ ) );
    define( 'EVERYBOARD_DIR_PATH', plugin_dir_path( __FILE__ ) );

    // Setup languages
    require_once dirname( __FILE__ ) . '/article-preview.php';
    require_once dirname( __FILE__ ) . '/widgetprefab/widgetprefab.php';
    require_once dirname( __FILE__ ) . '/board/board.php';
    require_once dirname( __FILE__ ) . '/settings/settings.php';
    require_once dirname( __FILE__ ) . '/list/list.php';
    require_once dirname( __FILE__ ) . '/dashboard/dashboard.php';

    $global_settings = new EveryBoard_Global_Settings( __FILE__ );
    new Everyboard_Dashboard();
} else {
    add_action( 'admin_init', 'everyboard_deactivate' );
    add_action( 'admin_notices', function () use ( $notice ) {
        everyboard_deactivation_notice( $notice );
    } );
}

/**
 * Function to check dependencies for Everyboard
 */
function everyboard_check_dependencies() {
    $notice = '';

    if ( !class_exists( 'OcAPI' ) ) {
        $notice = __( "<strong>EveryBoard</strong> needs the <strong>Open Content Everyware</strong> plugin to be activated and has therefore been <strong>deactivated</strong>.
            <br> Activate <strong>Open Content Everyware</strong> and try again", "everyboard" );
    } else if ( defined( 'EVERY_VERSION' ) && !everyboard_dependant_ew_version_loaded() ) {
        $eb_version = EVERYBOARD_VERSION;
        $ew_min_version = EVERYBOARD_EW_DEPENDENCY_MIN_VERSION;
        $notice = __( "<strong>EveryBoard {$eb_version}</strong> needs the <strong>Open Content Everyware version {$ew_min_version} </strong> or higher to be activated and has therefore been <strong>deactivated</strong>.", "everyboard" );
    }

    return $notice;
}

/**
 * @return bool
 *
 * Function to determine if a minimum version of everyware is loaded for everyboard
 */
function everyboard_dependant_ew_version_loaded() {
    $ew = str_replace( '.', '', EVERY_VERSION );
    $min_ew = str_replace( '.', '', EVERYBOARD_EW_DEPENDENCY_MIN_VERSION );

    $c_ew = strlen( $ew );
    $c_min_ew = strlen( $min_ew );

    if ( $c_ew < $c_min_ew ) {
        $number_of_zero = $c_min_ew - $c_ew;

        for ( $i = 0; $i < $number_of_zero; $i++ ) {
            $ew .= '0';
        }
    } else if ( $c_ew > $c_min_ew ) {
        $number_of_zero = $c_ew - $c_min_ew;

        for ( $i = 0; $i < $number_of_zero; $i++ ) {
            $c_min_ew .= '0';
        }
    }

    return (int)$ew >= (int)$min_ew;
}

/**
 * Function to deactivate EveryBoard
 */
function everyboard_deactivate() {
    deactivate_plugins( plugin_basename( __FILE__ ) );
}

if ( !function_exists( 'get_sites' ) ) {
    /**
     * Helper for WP-versions that don't yet have converted wp_get_sites
     *
     * @return array
     */
    function get_sites() {
        return array_map( function ( $site ) {
            return (object)$site;
        }, wp_get_sites() );
    }
}

/**
 * Function to notice the user when EveryBoard has been deactivated
 */
function everyboard_deactivation_notice( $notice ) {
    # Start HTML
    ?>
    <div class="updated">
        <p>
            <?php echo $notice; ?>
        </p>
    </div>

    <?php
    # End HTML
    echo '';
    if ( isset( $_GET['activate'] ) )
        unset( $_GET['activate'] );
}

global $pagenow;
if ( is_admin() && $pagenow == "widgets.php" ) {

    add_action( 'admin_enqueue_scripts', function () {

        wp_enqueue_style( 'ew-widget-extension-style', EVERYBOARD_BASE . 'assets/dist/css/boardwidgetextension.min.css' );
        wp_enqueue_script( "everyboard-widget-extension", EVERYBOARD_BASE . "assets/dist/js/widget-extension.min.ugly.js", array( 'jquery' ) );
        wp_enqueue_script( "every-selectize", EVERYBOARD_BASE . "assets/dist/js/selectize.js", array( "jquery" ) );
        wp_localize_script( 'everyboard-widget-extension', 'widgetTags', get_option( 'ew_board_wiget_tags' ) );
        wp_localize_script( 'everyboard-widget-extension', 'translation_widget_extension', array(
            'confirm_move_widget' => __( "Are you sure you want to move the widget from the Everyboard sidebar? Any active instance of the widget will be removed from the boards.", "everyboard" )
        ) );
    } );
}